DimensionsInfo

Struct DimensionsInfo 

#[non_exhaustive]
pub struct DimensionsInfo { pub dimensions: HashMap<String, String>, pub details: Option<QuotaDetails>, pub applicable_locations: Vec<String>, /* private fields */ }
The detailed quota information such as effective quota value for a combination of dimensions.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
dimensions: HashMap<String, String>

The map of dimensions in key-value pairs. The key of a map entry is “region”, “zone”, or the name of a service-specific dimension, and the value of a map entry is the value of the dimension. If a dimension does not appear in the map of dimensions, the dimensions info applies to all the dimension values except for those that have another DimensionInfo instance configured for the specific value. For example: {"provider" : "Example Organization"} where provider is a service-specific quota dimension and Example Organization is the provider name.

details: Option<QuotaDetails>

Quota details for the specified dimensions.

applicable_locations: Vec<String>

The applicable regions or zones of this dimension. The field is set to [‘global’] for quotas that are not per region or per zone. Otherwise, it will be set to the list of locations this dimension info is applicable to.

Implementations

Source

impl DimensionsInfo

pub fn new() -> Self

Creates a new default instance.

pub fn set_dimensions<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of dimensions.

Example
let x = DimensionsInfo::new().set_dimensions([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_details<T>(self, v: T) -> Self
where T: Into<QuotaDetails>,

Sets the value of details.

Example
use google_cloud_api_cloudquotas_v1::model::QuotaDetails;
let x = DimensionsInfo::new().set_details(QuotaDetails::default()/* use setters */);
pub fn set_or_clear_details<T>(self, v: Option<T>) -> Self
where T: Into<QuotaDetails>,

Sets or clears the value of details.

Example
use google_cloud_api_cloudquotas_v1::model::QuotaDetails;
let x = DimensionsInfo::new().set_or_clear_details(Some(QuotaDetails::default()/* use setters */));
let x = DimensionsInfo::new().set_or_clear_details(None::<QuotaDetails>);
pub fn set_applicable_locations<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of applicable_locations.

Example
let x = DimensionsInfo::new().set_applicable_locations(["a", "b", "c"]);