ListQuotaPreferencesRequest

Struct ListQuotaPreferencesRequest 

#[non_exhaustive]
pub struct ListQuotaPreferencesRequest { pub parent: String, pub page_size: i32, pub page_token: String, pub filter: String, pub order_by: String, /* private fields */ }
Message for requesting list of QuotaPreferences

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. Identifier. Parent value of QuotaPreference resources. Listing across different resource containers (such as ‘projects/-’) is not allowed.

When the value starts with ‘folders’ or ‘organizations’, it lists the QuotaPreferences for org quotas in the container. It does not list the QuotaPreferences in the descendant projects of the container.

Example parents: projects/123/locations/global

page_size: i32

Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.

page_token: String

Optional. A token identifying a page of results the server should return.

filter: String

Optional. Filter result QuotaPreferences by their state, type, create/update time range.

Example filters: reconciling=true AND request_type=CLOUD_CONSOLE, reconciling=true OR creation_time>2022-12-03T10:30:00

order_by: String

Optional. How to order of the results. By default, the results are ordered by create time.

Example orders: quota_id, service, create_time

Implementations

Source

impl ListQuotaPreferencesRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
ⓘ
let x = ListQuotaPreferencesRequest::new().set_parent(format!("projects/{project_id}/locations/{location_id}"));
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self

Sets the value of page_size.

Example
ⓘ
let x = ListQuotaPreferencesRequest::new().set_page_size(42);
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self

Sets the value of page_token.

Example
ⓘ
let x = ListQuotaPreferencesRequest::new().set_page_token("example");
pub fn set_filter<T: Into<String>>(self, v: T) -> Self

Sets the value of filter.

Example
ⓘ
let x = ListQuotaPreferencesRequest::new().set_filter("example");
pub fn set_order_by<T: Into<String>>(self, v: T) -> Self

Sets the value of order_by.

Example
ⓘ
let x = ListQuotaPreferencesRequest::new().set_order_by("example");