#[non_exhaustive]pub struct ListQuotaPreferencesRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
pub order_by: String,
/* private fields */
}Expand description
Message for requesting list of QuotaPreferences
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Identifier. Parent value of QuotaPreference resources. Listing across different resource containers (such as ‘projects/-’) is not allowed.
When the value starts with ‘folders’ or ‘organizations’, it lists the QuotaPreferences for org quotas in the container. It does not list the QuotaPreferences in the descendant projects of the container.
Example parents:
projects/123/locations/global
page_size: i32Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.
page_token: StringOptional. A token identifying a page of results the server should return.
filter: StringOptional. Filter result QuotaPreferences by their state, type, create/update time range.
Example filters:
reconciling=true AND request_type=CLOUD_CONSOLE,
reconciling=true OR creation_time>2022-12-03T10:30:00
order_by: StringOptional. How to order of the results. By default, the results are ordered by create time.
Example orders:
quota_id,
service, create_time
Implementations
Sourceimpl ListQuotaPreferencesRequest
impl ListQuotaPreferencesRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListQuotaPreferencesRequest::new().set_page_token("example");